@@ -7,9 +7,7 @@
 #include <gsl/gsl_errno.h>
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_odeiv.h>
-#if GSL_VERSION_MAJOR_FORTRAN >= 1 && GSL_VERSION_MINOR_FORTRAN >= 15
 #include <gsl/gsl_odeiv2.h>
-#endif
 #include <gsl/gsl_rng.h>
 #include <gsl/gsl_qrng.h>
 #include <gsl/gsl_integration.h>
@@ -27,18 +25,19 @@
 #include <gsl/gsl_monte_vegas.h>
 #include <gsl/gsl_permutation.h>
 #include <gsl/gsl_combination.h>
-#if GSL_VERSION_MAJOR_FORTRAN >= 1 && GSL_VERSION_MINOR_FORTRAN >= 14
 #include <gsl/gsl_multiset.h>
-#endif
 #include <gsl/gsl_wavelet.h>
 #include <gsl/gsl_vector.h>
 #include <gsl/gsl_matrix.h>
 // FIXME: remove after IBM compiler fixed
 #include <gsl/gsl_sf.h>
-
-#if GSL_VERSION_MAJOR_FORTRAN >= 1 && GSL_VERSION_MINOR_FORTRAN >= 16
 #include <gsl/gsl_multifit.h>
-#endif
+#include <gsl/gsl_multifit_nlinear.h>
+#include <gsl/gsl_multilarge.h>
+#include <gsl/gsl_multilarge_nlinear.h>
+#include <gsl/gsl_interp2d.h>
+#include <gsl/gsl_spmatrix.h>
+#include <gsl/gsl_splinalg.h>
 
 
 gsl_function *fgsl_function_cinit(double (*func)(double x, void *params), void *params) {
@@ -70,7 +69,7 @@ double fgsl_fn_fdf_eval_f_aux(gsl_function_fdf *f, double x) {
 double fgsl_fn_fdf_eval_df_aux(gsl_function_fdf *f, double x) {
     return GSL_FN_FDF_EVAL_DF(f,x);
 }
-void fgsl_fn_fdf_eval_f_df_aux(gsl_function_fdf *f, double x, double *y, 
+void fgsl_fn_fdf_eval_f_df_aux(gsl_function_fdf *f, double x, double *y,
 				double *dy) {
     GSL_FN_FDF_EVAL_F_DF(f,x,y,dy);
 }
@@ -102,18 +101,31 @@ gsl_vector *fgsl_aux_vector_double_init() {
     result->size = 0;
     return result;
 }
+gsl_vector_int *fgsl_aux_vector_int_init() {
+    gsl_vector_int *result;
+    result = (gsl_vector_int *) malloc(sizeof(gsl_vector_int));
+    result->block = (gsl_block_int *) malloc(sizeof(gsl_block_int));
+    result->owner = 0;
+    result->stride = 0;
+    result->size = 0;
+    return result;
+}
 void fgsl_aux_vector_double_free(gsl_vector *vec) {
     free(vec->block);
     free(vec);
 }
+void fgsl_aux_vector_int_free(gsl_vector_int *vec) {
+    free(vec->block);
+    free(vec);
+}
 
-int fgsl_aux_vector_double_align(double *a, size_t len, gsl_vector *fvec, size_t size, 
+int fgsl_aux_vector_double_align(double *a, size_t len, gsl_vector *fvec, size_t size,
 				 size_t offset, size_t stride) {
-    
+
     if (fvec == NULL || fvec->block == NULL) {
 	return GSL_EFAULT;
-    } 
-    if (offset + size*stride > len) {
+    }
+    if (offset + 1 + (size-1)*stride > len) {
 	return GSL_EINVAL;
     }
     fvec->block->size = len;
@@ -124,14 +136,38 @@ int fgsl_aux_vector_double_align(double *a, size_t len, gsl_vector *fvec, size_t
     fvec->owner = 0;
     return GSL_SUCCESS;
 }
+int fgsl_aux_vector_int_align(int *a, size_t len, gsl_vector_int *fvec, size_t size,
+         size_t offset, size_t stride) {
+
+    if (fvec == NULL || fvec->block == NULL) {
+  return GSL_EFAULT;
+    }
+    if (offset + 1 + (size-1)*stride > len) {
+  return GSL_EINVAL;
+    }
+    fvec->block->size = len;
+    fvec->block->data = a;
+    fvec->size = size;
+    fvec->stride = stride;
+    fvec->data = a+offset;
+    fvec->owner = 0;
+    return GSL_SUCCESS;
+}
+
 
 size_t fgsl_aux_vector_double_size(gsl_vector *fvec) {
     return fvec->size;
 }
+size_t fgsl_aux_vector_int_size(gsl_vector_int *fvec) {
+    return fvec->size;
+}
 
 size_t fgsl_aux_vector_double_stride(gsl_vector *fvec) {
     return fvec->stride;
 }
+size_t fgsl_aux_vector_int_stride(gsl_vector_int *fvec) {
+    return fvec->stride;
+}
 
 
 gsl_vector_complex *fgsl_aux_vector_complex_init() {
@@ -148,14 +184,14 @@ void fgsl_aux_vector_complex_free(gsl_vector_complex *vec) {
     free(vec);
 }
 
-int fgsl_aux_vector_complex_align(double *a, size_t len, 
-				  gsl_vector_complex *fvec, size_t size, 
+int fgsl_aux_vector_complex_align(double *a, size_t len,
+				  gsl_vector_complex *fvec, size_t size,
 				  size_t offset, size_t stride) {
-    
+
     if (fvec == NULL || fvec->block == NULL) {
 	return GSL_EFAULT;
-    } 
-    if (offset + size*stride > len) {
+    }
+    if (offset + 1 + (size-1)*stride > len) {
 	return GSL_EINVAL;
     }
     fvec->block->size = len;
@@ -191,10 +227,10 @@ void fgsl_aux_matrix_double_free(gsl_matrix *mat) {
 }
 
 int fgsl_aux_matrix_double_align(double *a, size_t lda, size_t n, size_t m, gsl_matrix *fvec) {
-    
+
     if (fvec == NULL || fvec->block == NULL) {
 	return GSL_EFAULT;
-    } 
+    }
     if (n > lda) {
 	return GSL_EINVAL;
     }
@@ -231,12 +267,12 @@ void fgsl_aux_matrix_complex_free(gsl_matrix_complex *mat) {
     free(mat);
 }
 
-int fgsl_aux_matrix_complex_align(double *a, size_t lda, size_t n, 
+int fgsl_aux_matrix_complex_align(double *a, size_t lda, size_t n,
 				  size_t m, gsl_matrix_complex *fvec) {
-    
+
     if (fvec == NULL || fvec->block == NULL) {
 	return GSL_EFAULT;
-    } 
+    }
     if (n > lda) {
 	return GSL_EINVAL;
     }
@@ -250,7 +286,7 @@ int fgsl_aux_matrix_complex_align(double *a, size_t lda, size_t n,
     return GSL_SUCCESS;
 }
 
-void fgsl_aux_matrix_complex_size(gsl_matrix_complex *fvec, 
+void fgsl_aux_matrix_complex_size(gsl_matrix_complex *fvec,
 				  size_t *lda, size_t *m, size_t *n) {
     if (m != NULL)
     	*m = fvec->size2;
@@ -260,6 +296,22 @@ void fgsl_aux_matrix_complex_size(gsl_matrix_complex *fvec,
     	*lda = fvec->tda;
 }
 
+const gsl_interp2d_type *fgsl_aux_interp2d_alloc(int i) {
+  const gsl_interp2d_type *res;
+  switch (i) {
+    case 1:
+      res = gsl_interp2d_bilinear;
+      break;
+    case 2:
+      res = gsl_interp2d_bicubic;
+      break;
+	  default:
+	    res = NULL;
+	    break;
+  }
+  return res;
+}
+
 const gsl_interp_type *fgsl_aux_interp_alloc(int i) {
     const gsl_interp_type *res;
     switch(i) {
@@ -282,6 +334,9 @@ const gsl_interp_type *fgsl_aux_interp_alloc(int i) {
 	case 6:
 	    res = gsl_interp_akima_periodic;
 	    break;
+	case 7:
+	    res = gsl_interp_steffen;
+	    break;
 	default:
 	    res = NULL;
 	    break;
@@ -292,9 +347,9 @@ const gsl_interp_type *fgsl_aux_interp_alloc(int i) {
     return res;
 }
 
-gsl_odeiv_system *fgsl_odeiv_system_cinit( 
-			     int (*func)(double t, const double y[], double dydt[], void * params), 
-			     size_t dimension, void *params, 
+gsl_odeiv_system *fgsl_odeiv_system_cinit(
+			     int (*func)(double t, const double y[], double dydt[], void * params),
+			     size_t dimension, void *params,
 			     int (*jacobian)(double t, const double y[], double * dfdy, double dfdt[], void * params)) {
     gsl_odeiv_system *result;
 // debug
@@ -317,10 +372,9 @@ gsl_odeiv_system *fgsl_odeiv_system_cinit(
     return result;
 }
 
-#if GSL_VERSION_MAJOR_FORTRAN >= 1 && GSL_VERSION_MINOR_FORTRAN >= 15
-gsl_odeiv2_system *fgsl_odeiv2_system_cinit( 
-			     int (*func)(double t, const double y[], double dydt[], void * params), 
-			     size_t dimension, void *params, 
+gsl_odeiv2_system *fgsl_odeiv2_system_cinit(
+			     int (*func)(double t, const double y[], double dydt[], void * params),
+			     size_t dimension, void *params,
 			     int (*jacobian)(double t, const double y[], double * dfdy, double dfdt[], void * params)) {
     gsl_odeiv2_system *result;
     result = (gsl_odeiv2_system *) malloc(sizeof(gsl_odeiv2_system));
@@ -330,18 +384,14 @@ gsl_odeiv2_system *fgsl_odeiv2_system_cinit(
     result->dimension = dimension;
     return result;
 }
-#endif
 
 void fgsl_odeiv_system_cfree(gsl_odeiv_system *system) {
     free(system);
 }
 
-#if GSL_VERSION_MAJOR_FORTRAN >= 1 && GSL_VERSION_MINOR_FORTRAN >= 15
 void fgsl_odeiv2_system_cfree(gsl_odeiv2_system *system) {
     free(system);
 }
-#endif
-
 
 const gsl_odeiv_step_type *fgsl_aux_odeiv_step_alloc(int i) {
     const gsl_odeiv_step_type *res;
@@ -386,7 +436,6 @@ const gsl_odeiv_step_type *fgsl_aux_odeiv_step_alloc(int i) {
     return res;
 }
 
-#if GSL_VERSION_MAJOR_FORTRAN >= 1 && GSL_VERSION_MINOR_FORTRAN >= 15
 const gsl_odeiv2_step_type *fgsl_aux_odeiv2_step_alloc(int i) {
     const gsl_odeiv2_step_type *res;
     switch(i) {
@@ -429,7 +478,43 @@ const gsl_odeiv2_step_type *fgsl_aux_odeiv2_step_alloc(int i) {
     }
     return res;
 }
-#endif
+
+const gsl_integration_fixed_workspace *gsl_aux_integration_fixed_alloc(int t, const size_t n, const double a, const double b, const double alpha, const double beta) {
+    const  gsl_integration_fixed_type *T;
+    switch(t) {
+	case 1:
+	    T = gsl_integration_fixed_legendre;
+	    break;
+	case 2:
+	    T = gsl_integration_fixed_chebyshev;
+	    break;
+	case 3:
+	    T = gsl_integration_fixed_gegenbauer;
+	    break;
+	case 4:
+	    T = gsl_integration_fixed_jacobi;
+	    break;
+	case 5:
+	    T = gsl_integration_fixed_laguerre;
+	    break;
+	case 6:
+	    T = gsl_integration_fixed_hermite;
+	    break;
+	case 7:
+	    T = gsl_integration_fixed_exponential;
+	    break;
+	case 8:
+	    T = gsl_integration_fixed_rational;
+	    break;
+	case 9:
+	    T = gsl_integration_fixed_chebyshev2;
+	    break;
+	default :
+	    T = NULL;
+	    break;
+    }
+    return gsl_integration_fixed_alloc(T, n, a, b, alpha, beta);
+}
 
 const gsl_rng_type *fgsl_aux_rng_assign(int i) {
     const gsl_rng_type *res;
@@ -652,7 +737,6 @@ const gsl_qrng_type *fgsl_aux_qrng_assign(int i) {
     return res;
 }
 
-#if GSL_VERSION_MAJOR_FORTRAN >= 1 && GSL_VERSION_MINOR_FORTRAN >= 16
 const gsl_multifit_robust_type *fgsl_aux_multifit_robust_alloc(int i) {
     const gsl_multifit_robust_type *res;
     switch (i) {
@@ -683,7 +767,6 @@ const gsl_multifit_robust_type *fgsl_aux_multifit_robust_alloc(int i) {
     }
     return res;
 }
-#endif
 
 const gsl_wavelet_type *fgsl_aux_wavelet_alloc(int i) {
     const gsl_wavelet_type *res;
@@ -746,9 +829,9 @@ void fgsl_monte_miser_cgetparams(gsl_monte_miser_state *s, double *estimate_frac
     *dither = s->dither;
 }
 
-void fgsl_monte_vegas_csetparams(gsl_monte_vegas_state *s, double result, 
-				 double sigma, double chisq, double alpha, 
-				 size_t iterations, int stage, int mode, 
+void fgsl_monte_vegas_csetparams(gsl_monte_vegas_state *s, double result,
+				 double sigma, double chisq, double alpha,
+				 size_t iterations, int stage, int mode,
 				 int verbose, FILE* ostream) {
     s->result = result;
     s->sigma = sigma;
@@ -760,9 +843,9 @@ void fgsl_monte_vegas_csetparams(gsl_monte_vegas_state *s, double result,
     s->verbose = verbose;
     s->ostream = ostream;
 }
-void fgsl_monte_vegas_cgetparams(gsl_monte_vegas_state *s, double *result, 
-				 double *sigma, double *chisq, double *alpha, 
-				 size_t *iterations, int *stage, int *mode, 
+void fgsl_monte_vegas_cgetparams(gsl_monte_vegas_state *s, double *result,
+				 double *sigma, double *chisq, double *alpha,
+				 size_t *iterations, int *stage, int *mode,
 				 int *verbose, FILE* ostream) {
     *result = s->result;
     *sigma = s->sigma;
@@ -833,7 +916,7 @@ const gsl_min_fminimizer_type *fgsl_aux_fminimizer_alloc(int i) {
     return res;
 }
 
-gsl_multiroot_function *fgsl_multiroot_function_cinit(int (*f)(const gsl_vector *x, void *params, 
+gsl_multiroot_function *fgsl_multiroot_function_cinit(int (*f)(const gsl_vector *x, void *params,
 							       gsl_vector *f), size_t n, void *params) {
     gsl_multiroot_function *result;
     result = (gsl_multiroot_function *) malloc(sizeof(gsl_multiroot_function));
@@ -858,6 +941,7 @@ gsl_multiroot_function_fdf *fgsl_multiroot_function_fdf_cinit(
     return result;
 }
 
+
 void fgsl_multiroot_function_cfree(gsl_multiroot_function *fun) {
     free(fun);
 }
@@ -865,6 +949,146 @@ void fgsl_multiroot_function_fdf_cfree(gsl_multiroot_function_fdf *fun) {
     free(fun);
 }
 
+gsl_multifit_nlinear_fdf *fgsl_multifit_nlinear_fdf_cinit(
+       size_t ndim, size_t p, void *params, 
+       int (*f)(const gsl_vector *x, void *params, gsl_vector *f), 
+       int (*df)(const gsl_vector *x, void *params, gsl_matrix *df), 
+       int (*fvv)(const gsl_vector *x, const gsl_vector *v, void *params, gsl_vector *vv) 
+       ) {
+    gsl_multifit_nlinear_fdf *result;
+    result = (gsl_multifit_nlinear_fdf *) malloc(sizeof(gsl_multifit_nlinear_fdf));
+    result->f = f;
+    result->df = df;
+    result->fvv = fvv;
+    result->n = ndim;
+    result->p = p;
+    result->params = params;
+    return result;
+}
+void fgsl_multifit_nlinear_fdf_cfree(gsl_multifit_nlinear_fdf *fun) {
+    free(fun);
+}
+
+const gsl_multifit_nlinear_trs *gsl_multifit_nlinear_get_trs(int i) {
+    const gsl_multifit_nlinear_trs *res;
+    switch(i) {
+	case 1:
+	    res = gsl_multifit_nlinear_trs_lm;
+	    break;
+	case 2:
+	    res = gsl_multifit_nlinear_trs_lmaccel;
+	    break;
+	case 3:
+	    res = gsl_multifit_nlinear_trs_dogleg;
+	    break;
+	case 4:
+	    res = gsl_multifit_nlinear_trs_ddogleg;
+	    break;
+	case 5:
+	    res = gsl_multifit_nlinear_trs_subspace2D;
+	    break;
+	default:
+	    res = NULL;
+	    break;
+    }
+    return res;
+}
+
+const gsl_multifit_nlinear_scale *gsl_multifit_nlinear_get_scale(int i) {
+    const gsl_multifit_nlinear_scale *res;
+    switch(i) {
+	case 1:
+	    res = gsl_multifit_nlinear_scale_levenberg;
+	    break;
+	case 2:
+	    res = gsl_multifit_nlinear_scale_marquardt;
+	    break;
+	case 3:
+	    res = gsl_multifit_nlinear_scale_more;
+	    break;
+	default:
+	    res = NULL;
+	    break;
+    }
+    return res;
+}
+
+const gsl_multifit_nlinear_solver *gsl_multifit_nlinear_get_solver(int i) {
+    const gsl_multifit_nlinear_solver *res;
+    switch(i) {
+	case 1:
+	    res = gsl_multifit_nlinear_solver_cholesky;
+	    break;
+	case 2:
+	    res = gsl_multifit_nlinear_solver_qr;
+	    break;
+	case 3:
+	    res = gsl_multifit_nlinear_solver_svd;
+	    break;
+	default:
+	    res = NULL;
+	    break;
+    }
+    return res;
+}
+
+void gsl_multifit_nlinear_fdf_get(gsl_multifit_nlinear_fdf *fdf, 
+       int (**fp)(const gsl_vector *x, void *params, gsl_vector *f),
+       int (**dfp)(const gsl_vector *x, void *params, gsl_matrix *df),
+       int (**fvvp)(const gsl_vector *x, const gsl_vector *v, void *params, gsl_vector *vv),
+       size_t *n, size_t *p, void **params, size_t *nevalf, size_t *nevaldf, size_t *nevalfvv) {
+
+       *fp = fdf->f; *dfp = fdf->df; *fvvp = fdf->fvv;
+       *n = fdf->n; *p = fdf->p; 
+       *params = fdf->params;
+       *nevalf = fdf->nevalf; *nevaldf = fdf->nevaldf; *nevalfvv = fdf->nevalfvv;
+}
+
+gsl_multifit_nlinear_type *gsl_multifit_nlinear_setup(char *s) {
+    return (gsl_multifit_nlinear_type *) gsl_multifit_nlinear_trust;
+}
+gsl_multilarge_nlinear_type *gsl_multilarge_nlinear_setup(char *s) {
+    return (gsl_multilarge_nlinear_type *) gsl_multilarge_nlinear_trust;
+}
+
+gsl_multilarge_nlinear_fdf *fgsl_multilarge_nlinear_fdf_cinit(
+       size_t ndim, size_t p, void *params, 
+       int (*f)(const gsl_vector *x, void *params, gsl_vector *f), 
+       int (*df)(CBLAS_TRANSPOSE_t TransJ, const gsl_vector * x,
+              const gsl_vector * u, void * params, gsl_vector * v,
+              gsl_matrix * JTJ),
+       int (*fvv)(const gsl_vector *x, const gsl_vector *v, void *params, gsl_vector *vv) 
+       ) {
+    gsl_multilarge_nlinear_fdf *result;
+    result = (gsl_multilarge_nlinear_fdf *) malloc(sizeof(gsl_multilarge_nlinear_fdf));
+    result->f = f;
+    result->df = df;
+    result->fvv = fvv;
+    result->n = ndim;
+    result->p = p;
+    result->params = params;
+    return result;
+}
+
+void fgsl_multilarge_nlinear_fdf_cfree(gsl_multilarge_nlinear_fdf *fun) {
+    free(fun);
+}
+
+void gsl_multilarge_nlinear_fdf_get(gsl_multilarge_nlinear_fdf *fdf, 
+       int (**fp)(const gsl_vector *x, void *params, gsl_vector *f),
+       int (**dfp)(CBLAS_TRANSPOSE_t TransJ, const gsl_vector *x, const gsl_vector *u, 
+           void *params, gsl_vector *v, gsl_matrix *jtj),
+       int (**fvvp)(const gsl_vector *x, const gsl_vector *v, void *params, gsl_vector *vv),
+       size_t *n, size_t *p, void **params, size_t *nevalf, size_t *nevaldfu, 
+       size_t *nevaldf2, size_t *nevalfvv) {
+
+       *fp = fdf->f; *dfp = fdf->df; *fvvp = fdf->fvv;
+       *n = fdf->n; *p = fdf->p; 
+       *params = fdf->params;
+       *nevalf = fdf->nevalf; *nevaldfu = fdf->nevaldfu; 
+       *nevaldf2 = fdf->nevaldf2; *nevalfvv = fdf->nevalfvv;
+}
+
 const gsl_multiroot_fsolver_type *fgsl_aux_multiroot_fsolver_alloc(int i) {
     const gsl_multiroot_fsolver_type *res;
     switch(i) {
@@ -885,7 +1109,66 @@ const gsl_multiroot_fsolver_type *fgsl_aux_multiroot_fsolver_alloc(int i) {
 	    break;
     }
     return res;
-    
+}
+
+const gsl_multilarge_nlinear_trs *gsl_multilarge_nlinear_get_trs(int i) {
+    const gsl_multilarge_nlinear_trs *res;
+    switch(i) {
+	case 1:
+	    res = gsl_multilarge_nlinear_trs_lm;
+	    break;
+	case 2:
+	    res = gsl_multilarge_nlinear_trs_lmaccel;
+	    break;
+	case 3:
+	    res = gsl_multilarge_nlinear_trs_dogleg;
+	    break;
+	case 4:
+	    res = gsl_multilarge_nlinear_trs_ddogleg;
+	    break;
+	case 5:
+	    res = gsl_multilarge_nlinear_trs_subspace2D;
+	    break;
+	case 6:
+	    res = gsl_multilarge_nlinear_trs_cgst;
+	    break;
+	default:
+	    res = NULL;
+	    break;
+    }
+    return res;
+}
+
+const gsl_multilarge_nlinear_scale *gsl_multilarge_nlinear_get_scale(int i) {
+    const gsl_multilarge_nlinear_scale *res;
+    switch(i) {
+	case 1:
+	    res = gsl_multilarge_nlinear_scale_levenberg;
+	    break;
+	case 2:
+	    res = gsl_multilarge_nlinear_scale_marquardt;
+	    break;
+	case 3:
+	    res = gsl_multilarge_nlinear_scale_more;
+	    break;
+	default:
+	    res = NULL;
+	    break;
+    }
+    return res;
+}
+
+const gsl_multilarge_nlinear_solver *gsl_multilarge_nlinear_get_solver(int i) {
+    const gsl_multilarge_nlinear_solver *res;
+    switch(i) {
+	case 1:
+	    res = gsl_multilarge_nlinear_solver_cholesky;
+	    break;
+	default:
+	    res = NULL;
+	    break;
+    }
+    return res;
 }
 
 const gsl_multiroot_fdfsolver_type *fgsl_aux_multiroot_fdfsolver_alloc(int i) {
@@ -908,10 +1191,25 @@ const gsl_multiroot_fdfsolver_type *fgsl_aux_multiroot_fdfsolver_alloc(int i) {
 	    break;
     }
     return res;
-    
 }
 
-gsl_multimin_function *fgsl_multimin_function_cinit(double (*f)(const gsl_vector *, void *), 
+const gsl_multilarge_linear_type *fgsl_aux_multilarge_linear_alloc(int i) {
+  const gsl_multilarge_linear_type *res;
+  switch (i) {
+    case 1:
+      res = gsl_multilarge_linear_normal;
+      break;
+    case 2:
+      res = gsl_multilarge_linear_tsqr;
+      break;
+    default:
+      res = NULL;
+      break;
+  }
+  return res;
+}
+
+gsl_multimin_function *fgsl_multimin_function_cinit(double (*f)(const gsl_vector *, void *),
 						    size_t n, void *params) {
     gsl_multimin_function *result;
     result = (gsl_multimin_function *) malloc(sizeof(gsl_multimin_function));
@@ -922,7 +1220,7 @@ gsl_multimin_function *fgsl_multimin_function_cinit(double (*f)(const gsl_vector
 }
 
 gsl_multimin_function_fdf *fgsl_multimin_function_fdf_cinit(
-    double (*f)(const gsl_vector *, void *), 
+    double (*f)(const gsl_vector *, void *),
     void (*df)(const gsl_vector *, void *, gsl_vector *),
     void (*fdf)(const gsl_vector *, void *, double *, gsl_vector *),
     size_t n, void *params) {
@@ -984,11 +1282,11 @@ const gsl_multimin_fdfminimizer_type *fgsl_aux_multimin_fdfminimizer_alloc(int i
 	    res = NULL;
 	    break;
     }
-    return res;   
+    return res;
 }
 
-gsl_multifit_function *fgsl_multifit_function_cinit(int (*f)(const gsl_vector *x, void *params, 
-							     gsl_vector *f), 
+gsl_multifit_function *fgsl_multifit_function_cinit(int (*f)(const gsl_vector *x, void *params,
+							     gsl_vector *f),
 						    size_t n, size_t p, void *params) {
     gsl_multifit_function *result;
     result = (gsl_multifit_function *) malloc(sizeof(gsl_multifit_function));
@@ -1022,7 +1320,6 @@ void fgsl_multifit_function_fdf_cfree(gsl_multifit_function_fdf *fun) {
     free(fun);
 }
 
-
 const gsl_multifit_fsolver_type *fgsl_aux_multifit_fsolver_alloc(int i) {
     const gsl_multifit_fsolver_type *res;
     switch(i) {
@@ -1031,7 +1328,7 @@ const gsl_multifit_fsolver_type *fgsl_aux_multifit_fsolver_alloc(int i) {
 	    break;
     }
     return res;
-    
+
 }
 
 const gsl_multifit_fdfsolver_type *fgsl_aux_multifit_fdfsolver_alloc(int i) {
@@ -1043,12 +1340,53 @@ const gsl_multifit_fdfsolver_type *fgsl_aux_multifit_fdfsolver_alloc(int i) {
 	case 2:
 	    res = gsl_multifit_fdfsolver_lmsder;
 	    break;
+	case 3:
+	    res = gsl_multifit_fdfsolver_lmniel;
+	    break;
 	default:
 	    res = NULL;
 	    break;
     }
     return res;
-    
+
+}
+
+const gsl_splinalg_itersolve_type *fgsl_aux_splinalg_itersolve_alloc(int i) {
+  const gsl_splinalg_itersolve_type *res;
+  switch(i) {
+    case 1:
+      res = gsl_splinalg_itersolve_gmres;
+      break;
+    default:
+      res = NULL;
+      break;
+  }
+  return res;
+}
+
+void gsl_spmatrix_size(gsl_spmatrix *m, size_t *n1, size_t *n2) {
+  *n1 = m->size1;
+  *n2 = m->size2;
+}
+
+void gsl_aux_spmatrix_getfields(gsl_spmatrix *m, int **i, double **data, int **p, size_t *psize) { 
+  *i    = m->i;
+  *data = m->data;
+  *p    = m->p;
+  switch (m->sptype) {
+    case GSL_SPMATRIX_COO:
+    *psize = m->nz;
+    break;
+    case GSL_SPMATRIX_CSC:
+    *psize = m->size2+1;
+    break;
+    case GSL_SPMATRIX_CSR:
+    *psize = m->size1+1;
+    break;
+    default:
+    *psize = 0;
+    break;
+  }
 }
 
 
@@ -1087,163 +1425,9 @@ gsl_vector *gsl_multifit_fdfsolver_dx(gsl_multifit_fdfsolver *s) {
 gsl_vector *gsl_multifit_fdfsolver_f(gsl_multifit_fdfsolver *s) {
     return s->f;
 }
-gsl_matrix *gsl_multifit_fdfsolver_jac(gsl_multifit_fdfsolver *s) {
+/*gsl_matrix *gsl_multifit_fdfsolver_jac(gsl_multifit_fdfsolver *s) {
     return s->J;
-}
-
-
-//FIXME: remove again once IBM compiler fixed
-
-double gsl_sf_bessel_jc0(const double x) {
-    return gsl_sf_bessel_J0(x);
-}
-int gsl_sf_bessel_jc0_e(const double x,  gsl_sf_result * result) {
-    return gsl_sf_bessel_J0_e(x, result);
-}
-
-double gsl_sf_bessel_jc1(const double x) {
-    return gsl_sf_bessel_J1(x);
-}
-int gsl_sf_bessel_jc1_e(const double x,  gsl_sf_result * result) {
-    return gsl_sf_bessel_J1_e(x, result);
-}
-
-double gsl_sf_bessel_jcn(const int n, const double x) {
-    return gsl_sf_bessel_Jn(n, x);
-}
-int gsl_sf_bessel_jcn_e(int n, const double x,  gsl_sf_result * result) {
-    return gsl_sf_bessel_Jn_e(n, x, result);
-}
-
-int gsl_sf_bessel_jcn_array(int nmin, int nmax, double x, double * result_array) {
-    return gsl_sf_bessel_Jn_array(nmin, nmax, x, result_array);
-}
-
-double gsl_sf_bessel_yc0(const double x) {
-    return gsl_sf_bessel_Y0(x);
-}
-int gsl_sf_bessel_yc0_e(const double x,  gsl_sf_result * result) {
-    return gsl_sf_bessel_Y0_e(x, result);
-}
-
-double gsl_sf_bessel_yc1(const double x) {
-    return gsl_sf_bessel_Y1(x);
-}
-int gsl_sf_bessel_yc1_e(const double x,  gsl_sf_result * result) {
-    return gsl_sf_bessel_Y1_e(x, result);
-}
-
-double gsl_sf_bessel_ycn(const int n, const double x) {
-    return gsl_sf_bessel_Yn(n, x);
-}
-int gsl_sf_bessel_ycn_e(int n, const double x,  gsl_sf_result * result) {
-    return gsl_sf_bessel_Yn_e(n, x, result);
-}
-
-int gsl_sf_bessel_ycn_array(int nmin, int nmax, double x, double * result_array) {
-    return gsl_sf_bessel_Yn_array(nmin, nmax, x, result_array);
-}
-
-double gsl_sf_bessel_ic0(const double x) {
-    return gsl_sf_bessel_I0(x);
-}
-int gsl_sf_bessel_ic0_e(const double x,  gsl_sf_result * result) {
-    return gsl_sf_bessel_I0_e(x, result);
-}
-
-double gsl_sf_bessel_ic0_scaled(const double x) {
-    return gsl_sf_bessel_I0_scaled(x);
-}
-int gsl_sf_bessel_ic0_scaled_e(const double x,  gsl_sf_result * result) {
-    return gsl_sf_bessel_I0_scaled_e(x, result);
-}
-
-double gsl_sf_bessel_ic1(const double x) {
-    return gsl_sf_bessel_I1(x);
-}
-int gsl_sf_bessel_ic1_e(const double x,  gsl_sf_result * result) {
-    return gsl_sf_bessel_I1_e(x, result);
-}
-
-double gsl_sf_bessel_ic1_scaled(const double x) {
-    return gsl_sf_bessel_I1_scaled(x);
-}
-int gsl_sf_bessel_ic1_scaled_e(const double x,  gsl_sf_result * result) {
-    return gsl_sf_bessel_I1_scaled_e(x, result);
-}
-
-double gsl_sf_bessel_icn(const int n, const double x) {
-    return gsl_sf_bessel_In(n, x);
-}
-int gsl_sf_bessel_icn_e(int n, const double x,  gsl_sf_result * result) {
-    return gsl_sf_bessel_In_e(n, x, result);
-}
-
-int gsl_sf_bessel_icn_array(int nmin, int nmax, double x, double * result_array) {
-    return gsl_sf_bessel_In_array(nmin, nmax, x, result_array);
-}
-
-double gsl_sf_bessel_icn_scaled(const int n, const double x) {
-    return gsl_sf_bessel_In_scaled(n, x);
-}
-int gsl_sf_bessel_icn_scaled_e(int n, const double x,  gsl_sf_result * result) {
-    return gsl_sf_bessel_In_scaled_e(n, x, result);
-}
-
-int gsl_sf_bessel_icn_scaled_array(int nmin, int nmax, double x, double * result_array) {
-    return gsl_sf_bessel_In_scaled_array(nmin, nmax, x, result_array);
-}
-
-double gsl_sf_bessel_kc0(const double x) {
-    return gsl_sf_bessel_K0(x);
-}
-int gsl_sf_bessel_kc0_e(const double x,  gsl_sf_result * result) {
-    return gsl_sf_bessel_K0_e(x, result);
-}
-
-double gsl_sf_bessel_kc0_scaled(const double x) {
-    return gsl_sf_bessel_K0_scaled(x);
-}
-int gsl_sf_bessel_kc0_scaled_e(const double x,  gsl_sf_result * result) {
-    return gsl_sf_bessel_K0_scaled_e(x, result);
-}
-
-double gsl_sf_bessel_kc1(const double x) {
-    return gsl_sf_bessel_K1(x);
-}
-int gsl_sf_bessel_kc1_e(const double x,  gsl_sf_result * result) {
-    return gsl_sf_bessel_K1_e(x, result);
-}
-
-double gsl_sf_bessel_kc1_scaled(const double x) {
-    return gsl_sf_bessel_K1_scaled(x);
-}
-int gsl_sf_bessel_kc1_scaled_e(const double x,  gsl_sf_result * result) {
-    return gsl_sf_bessel_K1_scaled_e(x, result);
-}
-
-double gsl_sf_bessel_kcn(const int n, const double x) {
-    return gsl_sf_bessel_Kn(n, x);
-}
-int gsl_sf_bessel_kcn_e(int n, const double x,  gsl_sf_result * result) {
-    return gsl_sf_bessel_Kn_e(n, x, result);
-}
-
-int gsl_sf_bessel_kcn_array(int nmin, int nmax, double x, double * result_array) {
-    return gsl_sf_bessel_Kn_array(nmin, nmax, x, result_array);
-}
-
-double gsl_sf_bessel_kcn_scaled(const int n, const double x) {
-    return gsl_sf_bessel_Kn_scaled(n, x);
-}
-int gsl_sf_bessel_kcn_scaled_e(int n, const double x,  gsl_sf_result * result) {
-    return gsl_sf_bessel_Kn_scaled_e(n, x, result);
-}
-
-int gsl_sf_bessel_kcn_scaled_array(int nmin, int nmax, double x, double * result_array) {
-    return gsl_sf_bessel_Kn_scaled_array(nmin, nmax, x, result_array);
-}    
-
+}*/
 
 size_t gsl_aux_sizeof_double() {
     return sizeof(double);
@@ -1277,11 +1461,9 @@ size_t gsl_aux_sizeof_combination() {
 }
 
 
-#if GSL_VERSION_MAJOR_FORTRAN >= 1 && GSL_VERSION_MINOR_FORTRAN >= 14
 size_t gsl_aux_sizeof_multiset() {
     return sizeof(gsl_multiset);
 }
-#endif
 size_t gsl_aux_sizeof_vector() {
     return sizeof(gsl_vector);
 }
